@@ -4,5 +4,5 @@ fn main() {
 
     // Make sure one feature at least is enabled
     #[cfg(all(not(feature = "json"), not(feature = "sqlite")))]
-    panic!("One feature at least must be enabled");
+    compile_error!("One feature at least must be enabled");
 }
